==> cucumber-groovy-1.1.4-sources.jar: cucumber/api/groovy/GL.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class GL {

    public static void Cando(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Cando(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dada(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dada(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dadas(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dadas(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dado(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dado(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dados(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dados(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void E(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void E(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Entón(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Entón(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Logo(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Logo(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Mais(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Mais(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Pero(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Pero(Pattern regexp, int timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

}

==> cucumber-groovy-1.1.5-sources.jar: cucumber/api/groovy/GL.java <==
package cucumber.api.groovy;

import groovy.lang.Closure;
import cucumber.runtime.groovy.*;

import java.util.regex.Pattern;

public class GL {

    public static void Cando(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Cando(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dada(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dada(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dadas(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dadas(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dado(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dado(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Dados(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Dados(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void E(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void E(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Entón(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Entón(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Logo(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Logo(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Mais(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Mais(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

    public static void Pero(Pattern regexp, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, 0, body);
    }

    public static void Pero(Pattern regexp, long timeoutMillis, Closure body) throws Throwable {
        GroovyBackend.instance.addStepDefinition(regexp, timeoutMillis, body);
    }

}
